// src/application-host/application-loader.js
import esbuild from "esbuild";
import { fileURLToPath } from "node:url";
import fs from "node:fs";
import { nodeResolve } from "dvlp/internal";
var IS_WIN32 = process.platform === "win32";
var RE_EXTS = /\.(tsx?|json)$/;
var port;
function initialize(data = {}) {
  port = data.port;
}
function resolve(specifier, context, nextResolve) {
  if (customHooks.onServerResolve !== void 0) {
    const resolved = customHooks.onServerResolve(
      specifier,
      context,
      (specifier2, context2) => doResolve(specifier2, context2, nextResolve)
    );
    resolved.shortCircuit = true;
    return resolved;
  }
  return doResolve(specifier, context, nextResolve);
}
function doResolve(specifier, context, nextResolve) {
  if (!specifier.startsWith("node:")) {
    const resolved = nodeResolve(
      specifier,
      context.parentURL ? fileURLToPath(context.parentURL) : void 0
    );
    if (resolved !== void 0) {
      resolved.shortCircuit = true;
      return resolved;
    }
  }
  return nextResolve(specifier, context);
}
function load(url, context, nextLoad) {
  port?.postMessage({
    type: "dependency",
    filePath: url.startsWith("file://") ? fileURLToPath(url) : url
  });
  if (customHooks.onServerTransform !== void 0) {
    const result = customHooks.onServerTransform(
      url,
      context,
      (url2, context2) => doLoad(url2, context2, nextLoad)
    );
    result.shortCircuit = true;
    return result;
  }
  return doLoad(url, context, nextLoad);
}
function doLoad(url, context, nextLoad) {
  if (RE_EXTS.test(new URL(url).pathname)) {
    const { format } = context;
    const filename = IS_WIN32 ? url : fileURLToPath(url);
    const source = fs.readFileSync(new URL(url), { encoding: "utf8" });
    const { code } = transform(source, filename, url, format);
    return { format: "module", source: code, shortCircuit: true };
  }
  return nextLoad(url, context);
}
function transform(source, filename, url, format) {
  const { code, warnings } = esbuild.transformSync(source.toString(), {
    sourcefile: filename,
    sourcemap: "inline",
    loader: new URL(url).pathname.match(RE_EXTS)[1],
    target: "node" + process.versions.node,
    format: "esm"
  });
  if (warnings && warnings.length > 0) {
    for (const warning of warnings) {
      console.warn(warning.location);
      console.warn(warning.text);
    }
  }
  return { code };
}
export {
  initialize,
  load,
  resolve
};
